@@ -26,6 +26,7 @@
 
 #include <src/udisksdaemontypes.h>
 #include "udiskslvm2types.h"
+#include "udisks-lvm2-generated.h"
 
 G_BEGIN_DECLS
 
@@ -39,7 +40,6 @@ void                 udisks_linux_logical_volume_update   (UDisksLinuxLogicalVol
                                                            UDisksLinuxVolumeGroupObject *group_object,
                                                            BDLVMLVdata                  *lv_info,
                                                            BDLVMLVdata                  *meta_lv_info,
-                                                           BDLVMLVdata                 **all_lv_infos,
                                                            gboolean                     *needs_polling_ret);
 void                   udisks_linux_logical_volume_update_etctabs (UDisksLinuxLogicalVolume     *logical_volume,
                                                                    UDisksLinuxVolumeGroupObject *group_object);
