@@ -150,9 +150,13 @@ const gchar        *udisks_client_get_partition_table_subtype_for_display (UDisk
                                                                            const gchar   *partition_table_type,
                                                                            const gchar   *partition_table_subtype);
 
+gchar *udisks_client_get_job_description_from_operation (const gchar *operation);
+
 gchar *udisks_client_get_job_description (UDisksClient   *client,
                                           UDisksJob      *job);
 
+G_DEFINE_AUTOPTR_CLEANUP_FUNC(UDisksClient, g_object_unref)
+
 /**
  * UDisksPartitionTypeInfo:
  * @table_type: A partition table type e.g. 'dos' or 'gpt'
@@ -178,9 +182,12 @@ struct _UDisksPartitionTypeInfo
   UDisksPartitionTypeInfoFlags  flags;
 };
 
+#define UDISKS_TYPE_PARTITION_TYPE_INFO (udisks_partition_type_info_get_type ())
 GType                udisks_partition_type_info_get_type   (void) G_GNUC_CONST;
 void                 udisks_partition_type_info_free       (UDisksPartitionTypeInfo  *info);
 
+G_DEFINE_AUTOPTR_CLEANUP_FUNC(UDisksPartitionTypeInfo, udisks_partition_type_info_free)
+
 G_END_DECLS
 
 #endif /* __UDISKS_CLIENT_H__ */
